AnnotationLayoutConfig class

Configuration for AnnotationLayoutEngine.layout.

Constructors

AnnotationLayoutConfig({required double annotationWidth, required double annotationHeight, required double maxVisibleDistance, required double paddingOverlap, double? yOffsetOverlap})
const

Properties

annotationHeight double
final
annotationWidth double
final
hashCode int
The hash code for this object.
no setterinherited
maxVisibleDistance double
final
paddingOverlap double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
yOffsetOverlap double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited