AnnotationLayoutEngine class

Pure Dart geometry engine: turns raw sensor data and a list of ArAnnotation into the subset that is visible, positioned and de-collided on screen.

Has no dependency on Flutter widgets/BuildContext/State, so it can be unit tested directly with package:test, without a WidgetTester.

Constructors

AnnotationLayoutEngine()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

layout({required List<ArAnnotation> annotations, required ArSensor arSensor, required Position deviceLocation, required double width, required double height, required AnnotationLayoutConfig config}) AnnotationLayoutResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited