arScale property
Scale of the label, set by the layout (see AnnotationLayoutConfig.scaleWithDistance). The label is scaled around its center.
Implementation
double arScale;
Scale of the label, set by the layout (see AnnotationLayoutConfig.scaleWithDistance). The label is scaled around its center.
double arScale;