onPreviewAspectRatio property
Called once the camera is initialized with the preview aspect ratio (long side / short side), needed to project POIs onto the preview.
Implementation
final ValueChanged<double>? onPreviewAspectRatio;
Called once the camera is initialized with the preview aspect ratio (long side / short side), needed to project POIs onto the preview.
final ValueChanged<double>? onPreviewAspectRatio;