ArCameraInfo class

Reads the back camera's optical characteristics from the platform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

backCameraFieldOfView() → Future<double?>
Field of view of the back camera along its long side, in degrees, or null when it cannot be determined.