backCameraFieldOfView static method

Future<double?> backCameraFieldOfView()

Field of view of the back camera along its long side, in degrees, or null when it cannot be determined.

Implementation

static Future<double?> backCameraFieldOfView() async {
  try {
    final fov = await _channel.invokeMethod<double>('backCameraFieldOfView');
    return fov != null && fov > 0 && fov < 180 ? fov : null;
  } on PlatformException {
    return null;
  } on MissingPluginException {
    return null;
  }
}