CompassEvent class

Constructors

CompassEvent.fromList(List<double>? data)

Properties

accuracy → double?
final
hashCode → int
The hash code for this object.
no setterinherited
heading → double?
final
headingForCameraMode → double?
final
rotationMatrix → List<double>?
Device attitude, see ArSensor.rotationMatrix. Null when the platform cannot provide it (e.g. no motion sensors on a simulator).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited