pitch property
Elevation of the camera axis in degrees: 0 when the device is held upright, negative when the camera points down.
Implementation
final double pitch;
Elevation of the camera axis in degrees: 0 when the device is held upright, negative when the camera points down.
final double pitch;