ArSensorManager class

Implemented types

Constructors

ArSensorManager()

Properties

arSensor Stream<ArSensor>
Stream of fused sensor samples.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
pitchHistory List<double>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Stops listening and releases resources.
override
init() → void
Starts listening to the underlying sensors and location updates.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited