init method
Starts listening to the underlying sensors and location updates.
Implementation
@override
void init() {
_arSensorController = StreamController();
_checkLocationPermission();
}
Starts listening to the underlying sensors and location updates.
@override
void init() {
_arSensorController = StreamController();
_checkLocationPermission();
}