ArSensorSource class abstract

Source of fused sensor + location samples consumed by ArView.

ArSensorManager is the default, device-backed implementation. Provide your own implementation (e.g. a fake/test double) via ArView.sensorSource to avoid depending on real hardware.

Implementers

Constructors

ArSensorSource()

Properties

arSensor Stream<ArSensor>
Stream of fused sensor samples.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Stops listening and releases resources.
init() → void
Starts listening to the underlying sensors and location updates.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited