ArStatus class

Constructors

ArStatus()

Properties

hashCode → int
The hash code for this object.
no setterinherited
heading ↔ double
getter/setter pair
hFov ↔ double
Champ de vision horizontal de l'appareil.
getter/setter pair
hPixelPerDegree ↔ double
getter/setter pair
pitch ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userLocation ↔ Position?
getter/setter pair
vFov ↔ double
champ de vision vertical de l'appareil
getter/setter pair
vPixelPerDegree ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited