ar_view library

Classes

ArView

Typedefs

AnnotationGroupBadgeBuilder = Widget Function(BuildContext context, ArAnnotation annotation, List<ArAnnotation> grouped)
Builds the badge shown on annotation's label when grouped annotations did not fit on screen and were grouped into it.
AnnotationViewBuilder = Widget Function(BuildContext context, ArAnnotation annotation)
Signature for a function that creates a widget for a given annotation.
ArSensorErrorBuilder = Widget Function(BuildContext context, ArSensorException error)
Builds the widget shown instead of the AR overlay when no location is available because the sensor source reported error.
ChangeLocationCallback = void Function(Position position)