ArProjection class
Pinhole model of the camera preview as displayed on screen.
The preview covers the view (see ArCamera), so the focal length in
pixels is the larger of the ones implied by each screen axis: the other
axis is cropped.
Constructors
- ArProjection({required double width, required double height, required double cameraFieldOfView, required double previewAspectRatio})
Properties
- focalLength → double
-
Focal length in logical pixels.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- horizontalFieldOfView → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verticalFieldOfView → double
-
no setter
- width → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
project(
List< double> rotation, List<double> worldDirection) → Offset? -
Projects a world direction (East, North, Up) seen with the attitude
rotationto a screen point, or null when it is behind the camera. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited